vim.cmd [[packadd packer.nvim]]
require('packer').startup(function(use)
    use 'wbthomason/packer.nvim'
    use 'nvim-lua/plenary.nvim'
    use {
        'nvim-treesitter/nvim-treesitter',
        run = function()
            require('nvim-treesitter.install').update({ with_sync = true })
        end
    }

    use {
        'nvim-lualine/lualine.nvim',
        requires = { 'kyazdani42/nvim-web-devicons', opt = true }
    }

    use {
        "zbirenbaum/copilot.lua",
        event = "VimEnter",
        config = function()
            vim.defer_fn(function()
                require('copilot').setup({
                    panel = {
                        enabled = false,
                        auto_refresh = false,
                        keymap = {
                            jump_prev = "[[",
                            jump_next = "]]",
                            accept = "<CR>",
                            refresh = "gr",
                            open = "<C-CR>"
                        },
                        layout = {
                            position = "right", -- | top | left | right
                            ratio = 0.4
                        }
                    },
                    suggestion = {
                        enabled = false,
                        auto_trigger = false,
                        debounce = 75,
                        keymap = {
                            accept = "<C-l>",
                            -- accept = "<Right>",
                            next = "<M-]>",
                            prev = "<M-[>",
                            dismiss = "<C-]>"
                        }
                    },
                    -- filetypes = {
                    --   yaml = false,
                    --   markdown = false,
                    --   help = false,
                    --   gitcommit = false,
                    --   gitrebase = false,
                    --   hgcommit = false,
                    --   svn = false,
                    --   cvs = false,
                    --   ["."] = false,
                    -- },
                    copilot_node_command = 'node', -- Node version must be < 18
                    plugin_manager_path = vim.fn.stdpath("data") ..
                        "/site/pack/packer",
                    server_opts_overrides = {
                        trace = "verbose",
                        settings = {
                            advanced = {
                                listCount = 10,        -- #completions for panel
                                inlineSuggestCount = 4 -- #completions for getCompletions
                            }
                        }
                    }
                })
            end, 100)
        end
    }

    use {
        "zbirenbaum/copilot-cmp",
        config = function()
            require("copilot_cmp").setup({
                suggestion = { enabled = false },
                panel = { enabled = false }
                -- method = "getCompletionsCycling",
                -- formatters = {
                --   insert_text = require("copilot_cmp.format").remove_existing
                -- }
            })
        end
    }

    use {
        "nvim-neorg/neorg",
        -- tag = "*",
        ft = "norg",
        after = "nvim-treesitter", -- You may want to specify Telescope here as well
        config = function()
            require('neorg').setup {
                load = {
                    ["core.defaults"] = {},                                 -- Loads default behaviour
                    ["core.concealer"] = {},                                -- Adds pretty icons to your documents
                    ["core.completion"] = { config = { engine = "nvim-cmp" } }, -- Adds completion
                    ["core.dirman"] = {                                     -- Manages Neorg workspaces
                        config = { workspaces = { notes = "~/notes" } }
                    }
                }
            }
        end
    }

    use { 'junegunn/fzf', run = function() vim.fn['fzf#install']() end }
    use 'junegunn/fzf.vim'
    use 'norcalli/nvim-colorizer.lua'
    use 'jiangmiao/auto-pairs'
    use 'pechorin/any-jump.vim'
    use 'tpope/vim-commentary'
    use 'tpope/vim-surround'
    use 'voldikss/vim-floaterm'
    use 'wakatime/vim-wakatime'

    use { 'akinsho/nvim-bufferline.lua' }
    use { 'andweeb/presence.nvim' }
    use { 'folke/which-key.nvim' }
    use { 'glepnir/dashboard-nvim' }
    use { 'kyazdani42/nvim-tree.lua' }
    use 'kyazdani42/nvim-web-devicons'
    use { 'lewis6991/gitsigns.nvim' }
    use { 'nvim-telescope/telescope.nvim' }
    use { 'nvim-telescope/telescope-file-browser.nvim' }
    use 'nvim-telescope/telescope-dap.nvim'
    use { 'ghassan0/telescope-glyph.nvim' }
    use {
        'nvim-telescope/telescope-fzf-native.nvim',
        run =
        'cmake -S. -Bbuild -DCMAKE_BUILD_TYPE=Release && cmake --build build --config Release && cmake --install build --prefix build'
    }

    use { 'ojroques/nvim-lspfuzzy' }

    use 'L3MON4D3/LuaSnip'
    -- use 'amrbashir/nvim-docs-view'
    use { 'hrsh7th/nvim-cmp' }
    use { 'hrsh7th/cmp-nvim-lsp' }
    use { 'hrsh7th/cmp-nvim-lua' }
    use { 'hrsh7th/cmp-nvim-lsp-signature-help' }
    use { 'hrsh7th/cmp-path' }
    use { 'hrsh7th/cmp-cmdline' }
    use { 'hrsh7th/cmp-buffer' }
    use { 'hrsh7th/cmp-nvim-lsp-document-symbol' }
    use {
        'j-hui/fidget.nvim',
        tag = 'legacy',
        config = function()
            require("fidget").setup {
                -- options
            }
        end
    }
    use { 'jose-elias-alvarez/null-ls.nvim' }
    use { 'https://git.sr.ht/~whynothugo/lsp_lines.nvim' }
    use { 'neovim/nvim-lspconfig' }
    use { 'onsails/lspkind-nvim' }
    -- use 'ray-x/lsp_signature.nvim'
    use { 'rmagatti/goto-preview' }
    use 'saadparwaiz1/cmp_luasnip'
    use({
        "jackMort/ChatGPT.nvim",
        commit = "24bcca7",
        requires = {
            "MunifTanjim/nui.nvim", "nvim-lua/plenary.nvim",
            "nvim-telescope/telescope.nvim"
        }
    })

    use({
        "iamcco/markdown-preview.nvim",
        run = function() vim.fn["mkdp#util#install"]() end
    })

    use 'folke/neodev.nvim'
    use 'mfussenegger/nvim-dap'
    use { "rcarriga/nvim-dap-ui", requires = { "mfussenegger/nvim-dap" } }
    use 'mfussenegger/nvim-dap-python'
    use 'theHamsta/nvim-dap-virtual-text'
    use { 'Mofiqul/dracula.nvim' }
    use({
        'NTBBloodbath/doom-one.nvim',
        setup = function()
            -- Add color to cursor
            vim.g.doom_one_cursor_coloring = false
            -- Set :terminal colors
            vim.g.doom_one_terminal_colors = true
            -- Enable italic comments
            vim.g.doom_one_italic_comments = false
            -- Enable TS support
            vim.g.doom_one_enable_treesitter = true
            -- Color whole diagnostic text or only underline
            vim.g.doom_one_diagnostics_text_color = false
            -- Enable transparent background
            vim.g.doom_one_transparent_background = false

            -- Pumblend transparency
            vim.g.doom_one_pumblend_enable = false
            vim.g.doom_one_pumblend_transparency = 20

            -- Plugins integration
            vim.g.doom_one_plugin_neorg = true
            vim.g.doom_one_plugin_barbar = false
            vim.g.doom_one_plugin_telescope = true
            vim.g.doom_one_plugin_neogit = true
            vim.g.doom_one_plugin_nvim_tree = true
            vim.g.doom_one_plugin_dashboard = true
            vim.g.doom_one_plugin_startify = true
            vim.g.doom_one_plugin_whichkey = true
            vim.g.doom_one_plugin_indent_blankline = true
            vim.g.doom_one_plugin_vim_illuminate = true
            vim.g.doom_one_plugin_lspsaga = false
        end,
        config = function()
            vim.cmd("colorscheme doom-one")
            vim.cmd(
                "highlight Pmenu ctermfg=white ctermbg=black gui=NONE guifg=white guibg=#282C34")
            vim.cmd("highlight PmenuSel guifg=purple guibg=red")
        end
    })
    use { 'olimorris/onedarkpro.nvim' }
    use { 'projekt0n/github-nvim-theme' }

    use { "catppuccin/nvim", as = "catppuccin" }
end)
